summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSven Eden <sven.eden@gmx.de>2013-02-01 16:27:43 +0100
committerSven Eden <sven.eden@gmx.de>2013-02-01 16:27:43 +0100
commit9d9098764e8d6f52ed506d500c061bb9878a62c8 (patch)
treef0647cb579b853dfa6e489ae0825a92bacf0b562 /ufed-curses-checklist.c
parentFixed F-Key descriptions (diff)
downloadufed-9d9098764e8d6f52ed506d500c061bb9878a62c8.tar.gz
ufed-9d9098764e8d6f52ed506d500c061bb9878a62c8.tar.bz2
ufed-9d9098764e8d6f52ed506d500c061bb9878a62c8.zip
Added a post-load analyzation to make use flags, that have only local descriptions which are all masked and/or forced unchangeable.
Diffstat (limited to 'ufed-curses-checklist.c')
-rw-r--r--ufed-curses-checklist.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/ufed-curses-checklist.c b/ufed-curses-checklist.c
index c8ccd65..c28a824 100644
--- a/ufed-curses-checklist.c
+++ b/ufed-curses-checklist.c
@@ -169,7 +169,8 @@ static void read_flags(void)
++lineNum;
} // loop through description lines
- // Add line data to the list stats
+ // Update flag states and add data to the list stats
+ genFlagStats(newFlag);
addLineStats(newFlag, &listStats);
} // loop while input given